@@ -161,6 +161,26 @@ class binance:
         finally:
             return response
 
+    def get_conditional_orders(self):
+        '''Function to get open orders'''
+        timestamp = self.get_server_time()
+        params = {
+            'timestamp': timestamp,
+        }
+        query_string = urlencode(params)
+        params['signature'] = hmac.new(self.API_SECRET.encode('utf-8'), query_string.encode('utf-8'), hashlib.sha256).hexdigest()
+        headers = {'X-MBX-APIKEY': self.API_KEY}
+        url = urljoin('https://api.binance.com','/api/v3/openOrders')
+        response = requests.get(url, headers=headers, params=params).json()
+        try:
+            code = response['code']
+            return ('Unable to get orders')
+        except:
+            if response==[]:
+                return {}
+        finally:
+            return response
+
     def create_limit_order(self,symbol,side,price,quantity):
         symbol = self.symbol_format(symbol)
         '''Function to create a limit order'''
@@ -213,6 +233,10 @@ class binance:
         headers = {'X-MBX-APIKEY': self.API_KEY}
         url = urljoin('https://api.binance.com','/api/v3/order')
         response = requests.post(url, headers=headers, params=params).json()
+        try:
+            response['price']=response['fills'][0]['price']
+        except:
+            pass
         return response
 
     def create_stop_loss_order(self,symbol,quantity,stopPrice):
@@ -475,10 +499,15 @@ class ftx:
 
     @authentication_required
     def get_open_orders(self, market: Optional[str] = None) -> List[dict]:
-        if market:
-            market=self.symbol_format(market)
         return self._get('orders', {'market': market})
 
+    @authentication_required
+    def get_conditional_orders(self,
+                               market: Optional[str] = None) -> List[dict]:
+        if market:
+            market = self.symbol_format(market)
+        return self._get('conditional_orders', {'market': market})
+
     @authentication_required
     def get_order_status(self, existing_order_id: int) -> dict:
         return self._get(f'orders/{existing_order_id}')
@@ -546,10 +575,7 @@ class ftx:
                 } if client_order_id is not None else {}),
             })
 
-    @authentication_required
-    def get_conditional_orders(self,
-                               market: Optional[str] = None) -> List[dict]:
-        return self._get('conditional_orders', {'market': self.symbol_format(market)})
+
 
     @authentication_required
     def place_order(self,
@@ -807,7 +833,7 @@ class ftx:
 
 
     def get_exchange_info(self):
-        '''Function to get server time'''
+        '''Function to get exchange information'''
         response = requests.get(self._base_url+'/markets',params={}).json()
         try:
             return response
@@ -817,11 +843,10 @@ class ftx:
 
     def get_price_precision(self,symbol):
         symbol = self.symbol_format(symbol)
-        
         try:
             info = self.get_exchange_info()['result']
             for pair in info:
-                if pair==symbol:
+                if pair['name']==symbol:
                     return pair["priceIncrement"]
             return {'error':'No matching symbol'}
         except Exception as e:
@@ -864,7 +889,9 @@ class ftx:
     def create_market_order(self,symbol,side,quantity):
         symbol = self.symbol_format(symbol)
         try:
-            return self.place_order(symbol,side,0,quantity,"market")
+            order = self.place_order(symbol,side,0,quantity,"market")
+            order['price']=self.get_order_status(order["id"])["avgFillPrice"]
+            return order
         except:
             return {'msg':Exception}
 
@@ -925,6 +952,6 @@ if __name__=='__main__':
     broker = ftx()
     symbol = 'BTC*USDT'
     broker.connect_key('ftx.key')
-    print(broker.get_open_orders()[0])
+    print(broker.get_conditional_orders())
     
         
\ No newline at end of file
